AnyBoxBorder class

Rectangular border with independent side and corner overrides.

Inheritance

Constructors

AnyBoxBorder({double? ratio, AnyBoxShape shape = AnyBoxShape.rectangle, AnyCorner? corners, AnyCorner? innerCorners, AnySide? sides, AnySide? left, AnySide? top, AnySide? right, AnySide? bottom, AnySide? horizontal, AnySide? vertical, AnyCorner? topLeft, AnyCorner? topRight, AnyCorner? bottomRight, AnyCorner? bottomLeft, AnyCorner? innerTopLeft, AnyCorner? innerTopRight, AnyCorner? innerBottomRight, AnyCorner? innerBottomLeft})
const

Properties

bottom AnySide?
Side used for the bottom edge.
final
bottomLeft AnyCorner?
Outer corner used at the bottom-left point.
final
bottomRight AnyCorner?
Outer corner used at the bottom-right point.
final
corners AnyCorner
Default outer corner used by point when no point-specific corner is provided.
finalinherited
hashCode int
The hash code for this object.
no setteroverride
horizontal AnySide?
Fallback side used by the top and bottom edges.
final
innerBottomLeft AnyCorner?
Inner corner used at the bottom-left point.
final
innerBottomRight AnyCorner?
Inner corner used at the bottom-right point.
final
innerCorners AnyCorner?
Default inner corner used by point when no point-specific corner is provided.
finalinherited
innerTopLeft AnyCorner?
Inner corner used at the top-left point.
final
innerTopRight AnyCorner?
Inner corner used at the top-right point.
final
left AnySide?
Side used for the left edge.
final
ratio double?
Optional width / height ratio used to fit the contour inside the paint size.
finalinherited
Side used for the right edge.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sides AnySide
Default side used by point when no point-specific side is provided.
finalinherited
top AnySide?
Side used for the top edge.
final
topLeft AnyCorner?
Outer corner used at the top-left point.
final
topRight AnyCorner?
Outer corner used at the top-right point.
final
vertical AnySide?
Fallback side used by the left and right edges.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override