AnyContour class
Constructors
-
AnyContour({required AnyFill? background, required AnyShapeBase backgroundBase, required AnyShapeBase clipBase, required AnyShapeBase shadowBase, required List<
AnyPoint> points})
Properties
- background → AnyFill?
-
final
- backgroundBase → AnyShapeBase
-
final
- backgroundPath → Path?
-
no setter
- clipBase → AnyShapeBase
-
final
- clipPath → Path
-
no setter
- cornerAngle ↔ Float64List
-
latefinal
- cornerMatrix00 ↔ Float64List
-
latefinal
- cornerMatrix01 ↔ Float64List
-
latefinal
- cornerMatrix10 ↔ Float64List
-
latefinal
- cornerMatrix11 ↔ Float64List
-
latefinal
- cornerParallel ↔ Uint8List
-
latefinal
- cornerSegments ↔ Int32List
-
latefinal
- cornerSin ↔ Float64List
-
latefinal
- cornerTurnSign ↔ Int8List
-
latefinal
- count ↔ int
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
-
innerCorners
↔ List<
AnyCorner> -
getter/setter pair
-
outerCorners
↔ List<
AnyCorner> -
getter/setter pair
- pointX ↔ Float64List
-
latefinal
- pointY ↔ Float64List
-
latefinal
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- shadowBase → AnyShapeBase
-
final
- shadowPath → Path
-
no setter
- sideDirectionX ↔ Float64List
-
latefinal
- sideDirectionY ↔ Float64List
-
latefinal
- sideHasWidth ↔ Uint8List
-
latefinal
- sideInsideNormalX ↔ Float64List
-
latefinal
- sideInsideNormalY ↔ Float64List
-
latefinal
- sideInsideOffset ↔ Float64List
-
latefinal
- sideLength ↔ Float64List
-
latefinal
- sideOutsideOffset ↔ Float64List
-
latefinal
- sidePainted ↔ Uint8List
-
latefinal
-
sides
↔ List<
AnySide> -
latefinal
-
zeroCorners
↔ List<
AnyCorner> -
getter/setter pair
Methods
-
cornerHandedness(
int cornerIndex) → double -
isCornerParallel(
int cornerIndex) → bool -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
offsetForBase(
int sideIndex, AnyShapeBase base) → double -
regions(
{required bool backgroundMerge}) → AnyRegions -
shiftedClipPath(
Offset offset) → Path -
shiftedRegions(
{required Offset offset, required bool backgroundMerge}) → AnyRegions -
shiftedShadowPath(
Offset offset) → Path -
toString(
) → String -
A string representation of this object.
inherited
-
worldPointFromDistanceSpace(
int cornerIndex, double dPrev, double dNext) → (double, double) -
wrap(
int index) → int
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited