AnyCorner class abstract

Implementers

Constructors

AnyCorner({double p = 0.0, double n = 0.0})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
isCircular bool
no setter
n double
Corner extent along the next side.
final
p double
Corner extent along the previous side.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

appendArc(Path path, AnyContour contour, int cornerIndex, double dPrev, double dNext, double fromAngle, double toAngle) → void
canBuild(AnyContour contour, int cornerIndex) bool
consumptionForNextSide(AnyContour contour, int cornerIndex) double
consumptionForPreviousSide(AnyContour contour, int cornerIndex) double
convert(double insetP, double insetN, bool inner, double angle) AnyCorner
Creates an auto-derived inner/outer corner for the provided adjacent side insets. insetP = inset on previous side insetN = inset on next side inner = convex/inner turn conversion angle = local corner angle in radians
copyWith({double? p, double? n}) AnyCorner
lerpTo(AnyCorner other, double t) AnyCorner
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
pointAt(AnyContour contour, int cornerIndex, double dPrev, double dNext, double angle) → (double, double)
resolvedNext(double maxNextExtent) double
resolvedPrevious(double maxPreviousExtent) double
resolveFinite(double maxPreviousExtent, double maxNextExtent) AnyCorner
scaleForNextSide(double factor) AnyCorner
scaleForPreviousSide(double factor) AnyCorner
toString() String
A string representation of this object.
inherited
turnSign(AnyContour contour, int cornerIndex) double

Operators

operator *(double factor) AnyCorner
operator ==(Object other) bool
The equality operator.
inherited