AnyPoint class
One source point in an AnyDecoration contour.
The point defines a vertex of the contour. Its outer and optional inner corners describe how the contour bends at this point, while side describes the border segment painted from this point to the next point.
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- inner → AnyCorner?
-
Optional corner used for the inner contour band at this point.
final
- outer → AnyCorner
-
Corner used for the outer contour band at this point.
final
- point → Offset
-
Vertex position in local decoration coordinates.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- side → AnySide
-
Side painted from this point to the next contour point.
final
- skip → bool
-
Whether this point should be ignored when building the contour geometry.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited