AnyRegions class

Constructors

AnyRegions({(AnyFill, Path)? background, List<(AnyFill, Path)> regions = const []})
const

Properties

background → (AnyFill, Path)?
final
hashCode int
The hash code for this object.
no setterinherited
regions List<(AnyFill, Path)>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
withOffset(Offset offset) AnyRegions

Operators

operator ==(Object other) bool
The equality operator.
inherited