alignInside constant
double
const alignInside
Places the full side width inside the source contour.
Implementation
static const double alignInside = -1;
Places the full side width inside the source contour.
static const double alignInside = -1;