alignOutside constant
double
const alignOutside
Places the full side width outside the source contour.
Implementation
static const double alignOutside = 1;
Places the full side width outside the source contour.
static const double alignOutside = 1;