AnyDecorationCache class

Small shared cache for contours.

Constructors

AnyDecorationCache()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

limit ↔ int
getter/setter pair

Static Methods

clear() → void
get(AnyDecorationCacheKey key) → List<AnyContour>?
put(AnyDecorationCacheKey key, List<AnyContour> contours) → void