createBasePaint abstract method
Creates a configured paint for the base fill, or null if there is none.
Implementation
Paint? createBasePaint(Path path, ImageConfiguration configuration);
Creates a configured paint for the base fill, or null if there is none.
Paint? createBasePaint(Path path, ImageConfiguration configuration);