image property
DecorationImage?
get
image
Image painted into the target path before the base fill.
Implementation
DecorationImage? get image;
Image painted into the target path before the base fill.
DecorationImage? get image;