AnyShadow class

Mixed-in types

Constructors

AnyShadow({Color? color, Gradient? gradient, DecorationImage? image, BlendMode? blendMode, double blurRadius = 0.0, Offset offset = Offset.zero, Offset spreadRadius = Offset.zero, BlurStyle style = BlurStyle.normal, bool isAntiAlias = true, bool offsetClip = false})
const

Properties

blendMode BlendMode?
Blend mode applied to the paint created for color or gradient.
final
blurRadius double
final
blurSigma double
no setter
color Color?
Solid color used as the base fill.
final
gradient Gradient?
Gradient used as the base fill.
final
hasBaseFill bool
Whether this fill has a color or gradient base fill.
no setterinherited
hasFill bool
Whether this fill has any paintable content.
no setterinherited
hashCode int
The hash code for this object.
no setteroverride
image DecorationImage?
Image painted into the target path before the base fill.
final
isAntiAlias bool
Whether path painting should use anti-aliasing.
final
offset Offset
final
offsetClip bool
Controls whether the clip/cutout path used by BlurStyle.inner, BlurStyle.outer, and BlurStyle.solid follows offset.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
spreadRadius Offset
final
style BlurStyle
final

Methods

createBasePaint(Path path, ImageConfiguration configuration) Paint?
Creates a configured paint for the base fill, or null if there is none.
inherited
isSameAs(AnyFill? other) bool
Returns true when this fill has the same visual fill options as other.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
paint(Canvas canvas, Path path, ImageConfiguration configuration, DecorationImagePainter? painterOf(AnyFill)) → void
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override