AnyUtils class abstract

Constructors

AnyUtils()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

clamp01(double value) double
clampDouble(double value, double min, double max) double
nearZero(double value, [double epsilon = AnyUtils.epsilon]) bool
pickLerp<T>(T a, T b, double t) → T
pickLerpNullable<T>(T? a, T? b, double t) → T?

Constants

endAnglePi1d5 → const double
epsilon → const double
midAngle1d25 → const double
quarterSweepPi0d5 → const double
startAnglePi1d → const double