any_borders library
Classes
- AnyBackground
- Fill painted behind the side regions of an AnyDecoration.
- AnyBorder
- Base class for borders built for AnyDecoration.
- AnyBoxBorder
- Rectangular border with independent side and corner overrides.
- AnyBoxDecoration
- Rectangular AnyDecoration with independent side and corner overrides.
- AnyContour
- AnyCorner
- AnyDecoration
- Base class for decorations built from arbitrary contour points.
- AnyDecorationCache
- Small shared cache for contours.
- AnyDecorationTween
- AnyFill
- Shared fill contract for decorations, sides, backgrounds, and shadows.
- AnyPoint
- One source point in an AnyDecoration contour.
- AnyRegions
- AnyShadow
- AnySide
- Fill and geometry for one contour side.
- BevelCorner
- InverseRoundedCorner
- RoundedCorner