any_contour library

Classes

AnyBackground
Fill painted behind the side regions of an AnyDecoration.
AnyBorder
Base class for borders built for AnyDecoration.
AnyContour
AnyCorner
AnyDecoration
Base class for decorations built from arbitrary contour points.
AnyPoint
One source point in an AnyDecoration contour.
AnyRegions
AnySide
Fill and geometry for one contour side.
BevelCorner
InverseRoundedCorner
RoundedCorner