AnyBackground class
Fill painted behind the side regions of an AnyDecoration.
- Mixed-in types
Constructors
- AnyBackground({Color? color, Gradient? gradient, DecorationImage? image, BlendMode? blendMode, bool isAntiAlias = true, AnyShapeBase shapeBase = AnyShapeBase.zeroBorder})
-
const
Properties
- blendMode → BlendMode?
-
Blend mode applied to the background base fill.
final
- color → Color?
-
Solid color used as the background base fill.
final
- gradient → Gradient?
-
Gradient used as the background base fill.
final
- hasBaseFill → bool
-
Whether this fill has a color or gradient base fill.
no setterinherited
- hasFill → bool
-
Whether this fill has any paintable content.
no setterinherited
- hashCode → int
-
The hash code for this object.
no setteroverride
- image → DecorationImage?
-
Image painted into the background path.
final
- isAntiAlias → bool
-
Whether the background path should be anti-aliased.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- shapeBase → AnyShapeBase
-
Contour band used to build the background path.
final
Methods
-
copyWith(
{AnyShapeBase? shapeBase, Color? color, Gradient? gradient, DecorationImage? image, BlendMode? blendMode, bool? isAntiAlias}) → AnyBackground -
createBasePaint(
Path path, ImageConfiguration configuration) → Paint? -
Creates a configured paint for the base fill, or null if there is none.
inherited
-
isSameAs(
AnyFill? other) → bool -
Returns true when this fill has the same visual fill options as
other.inherited -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Static Methods
-
lerp(
AnyBackground? a, AnyBackground? b, double t) → AnyBackground?