AnyBorder class
Base class for borders built for AnyDecoration.
- Implementers
Constructors
Properties
- corners → AnyCorner
-
Default source-shape corner used by AnyDecoration.point.
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- innerCorners → AnyCorner?
-
Default explicit inner corner; null derives it from the shape.
final
- offset → double
-
Path displacement in logical units, added to AnyDecoration.offset.
Negative values inset; positive values outset. Must be finite.
final
- outerCorners → AnyCorner?
-
Default explicit outer corner; null derives it from the shape.
final
- ratio → double?
-
Optional width / height ratio used to fit the contour inside the paint size.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sides → AnySide
-
Default side used by AnyDecoration.point.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override