AnyBorder class

Base class for borders built for AnyDecoration.

Implementers

Constructors

AnyBorder({AnySide? sides, AnyCorner? corners, AnyCorner? innerCorners, double? ratio})
const

Properties

corners AnyCorner
Default outer corner used by point when no point-specific corner is provided.
final
hashCode int
The hash code for this object.
no setteroverride
innerCorners AnyCorner?
Default inner corner used by point when no point-specific corner is provided.
final
ratio double?
Optional width / height ratio used to fit the contour inside the paint size.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sides AnySide
Default side used by point when no point-specific side is provided.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override