AnySide class
Fill and geometry for one contour side.
Sides are assigned to AnyPoint entries and are painted between that point and the next point in the contour.
- Mixed-in types
Constructors
Properties
- align → double
-
Align means align relative to the corresponding side, not the whole shape.
final
- blendMode → BlendMode?
-
Blend mode applied to the side base fill.
final
- color → Color?
-
Solid color used as the side base fill.
final
- gradient → Gradient?
-
Gradient used as the side base fill.
final
- hasBaseFill → bool
-
Whether this fill has a color or gradient base fill.
no setterinherited
- hasFill → bool
-
Whether this fill has any paintable content.
no setterinherited
- hashCode → int
-
The hash code for this object.
no setteroverride
- image → DecorationImage?
-
Image painted into the side path.
final
- isAntiAlias → bool
-
Whether side paths should be anti-aliased.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- width → double
-
Stroke width for this side.
final
Methods
-
copyWith(
{double? width, double? align, Color? color, Gradient? gradient, DecorationImage? image, BlendMode? blendMode, bool? isAntiAlias}) → AnySide -
createBasePaint(
Path path, ImageConfiguration configuration) → Paint? -
Creates a configured paint for the base fill, or null if there is none.
inherited
-
isSameAs(
AnyFill? other) → bool -
Returns true when this fill has the same visual fill options as
other.inherited -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
- alignCenter → const double
- Centers the side width on the source contour.
- alignInside → const double
- Places the full side width inside the source contour.
- alignOutside → const double
- Places the full side width outside the source contour.