AnyFill class abstract
Shared fill contract for decorations, sides, backgrounds, and shadows.
An AnyFill can paint a solid color, a gradient, an image, or a combination of a base fill and an image. Implementers usually mix in MAnyFill to get consistent fill comparison and paint creation behavior.
- Implementers
Constructors
- AnyFill()
Properties
- blendMode → BlendMode?
-
Blend mode applied to the paint created for color or gradient.
no setter
- color → Color?
-
Solid color used as the base fill.
no setter
- gradient → Gradient?
-
Gradient used as the base fill.
no setter
- hasBaseFill → bool
-
Whether this fill has a color or gradient base fill.
no setter
- hasFill → bool
-
Whether this fill has any paintable content.
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- image → DecorationImage?
-
Image painted into the target path before the base fill.
no setter
- isAntiAlias → bool
-
Whether path painting should use anti-aliasing.
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
createBasePaint(
Path path, ImageConfiguration configuration) → Paint? - Creates a configured paint for the base fill, or null if there is none.
-
isSameAs(
AnyFill other) → bool -
Returns true when this fill has the same visual fill options as
other. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited